@@ -13,14 +13,7 @@ class S3FsClass(AbstractFSClass):
     s3_fs = None
 
     def __init__(self, s3_parameters):
-        self.os_fs = open_fs('osfs://')
-        self.s3_fs = open_fs(
-            's3://{}:{}@{}'.format(
-                s3_parameters['access_key_id'],
-                s3_parameters['secret_access_key'],
-                s3_parameters['bucket']
-            )
-        )
+        self.reinit(s3_parameters)
 
     def bytes_write(self, destination_path, destination_file, mbytes):
         self.s3_fs.makedirs(destination_path, recreate=True)
@@ -68,3 +61,13 @@ class S3FsClass(AbstractFSClass):
 
         with self.os_fs.open(destination_file) as local_file:
             return local_file.read()
+
+    def reinit(self, s3_parameters):
+        self.os_fs = open_fs('osfs://')
+        self.s3_fs = open_fs(
+            's3://{}:{}@{}'.format(
+                s3_parameters['access_key_id'],
+                s3_parameters['secret_access_key'],
+                s3_parameters['bucket']
+            )
+        )
